"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AutoComplete = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const react_native_themes_1 = require("@brightlayer-ui/react-native-themes");
const Chip_1 = require("../Chip");
const MaterialIcons_1 = __importDefault(require("react-native-vector-icons/MaterialIcons"));
const AutocompleteStyles = (theme, filterOptions, selected) => react_native_1.StyleSheet.create({
    optionText: { color: theme.colors.onSurfaceVariant, marginHorizontal: 16 },
    labelStyle: {
        paddingTop: 4,
        paddingHorizontal: 6,
        paddingVertical: 0,
        color: selected ? theme.colors.onSurfaceVariant : theme.colors.primary,
    },
    individualTextInputWrapper: {
        marginHorizontal: -1,
        marginVertical: 4,
        minHeight: 20,
        overflow: 'hidden',
        backgroundColor: 'rgba(255, 255, 255, 0)',
    },
    iconWrapper: { width: '7%', paddingTop: 8 },
    selectorContainer: {
        backgroundColor: theme.colors.surfaceVariant,
        borderTopLeftRadius: 4,
        borderTopRightRadius: 4,
        borderBottomWidth: 2,
        paddingTop: 8,
        paddingBottom: 8,
        paddingHorizontal: 10,
        borderBottomColor: selected ? theme.colors.onSurfaceVariant : theme.colors.primary,
        flexDirection: 'row',
        flexWrap: 'wrap',
        flexGrow: 0,
        flex: 1,
    },
    chip: {
        marginHorizontal: 6,
        marginVertical: 6,
    },
    dropDownItem: {
        paddingBottom: 12,
        flexDirection: 'row',
        flex: 1,
    },
    tagTextInput: {
        fontSize: 16,
        marginTop: react_native_1.Platform.OS === 'android' ? 0 : 13,
        marginLeft: react_native_1.Platform.OS === 'android' ? 4 : 8,
        marginBottom: react_native_1.Platform.OS === 'android' ? 0 : 13,
    },
    tagInput: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        flexGrow: 0,
        flex: 1,
        alignItems: 'flex-start',
        justifyContent: 'flex-start',
        paddingRight: 12,
    },
    dropDownMenuTags: {
        paddingRight: 16,
        backgroundColor: theme.colors.surfaceVariant,
        paddingTop: filterOptions.length < 1 ? 0 : 12,
        paddingBottom: filterOptions.length < 1 ? 0 : 6,
        maxHeight: 150,
        borderBottomLeftRadius: 4,
        borderBottomRightRadius: 4,
    },
    tagInputWrapper: { paddingTop: 5, paddingHorizontal: 2, flexShrink: 1 },
    bottomMargin: {
        paddingBottom: 18,
    },
    helpersWrapper: {
        flexDirection: 'row',
        justifyContent: 'space-between',
    },
    helper: {
        flexShrink: 1,
    },
    counterHelper: {
        textAlign: 'right',
    },
});
const AutoComplete = (props) => {
    const { theme: themeOverride, value = [], options = [], limitTags = 6, limitCharacterCountTag = 16, helperText, tagInputFieldProps, chipProps, onChange, onDelete, label = '', styles, disabled = false, allowCustomtag = false, } = props;
    const theme = (0, react_native_themes_1.useExtendedTheme)(themeOverride);
    function filterChips(chipOptions, chipValue) {
        return chipOptions.filter((option) => chipValue.findIndex((item) => item === option) === -1);
    }
    const [filterOptions, setFilterOptions] = (0, react_1.useState)(filterChips(options, value));
    const [hideDropDownTags, setHideDropDownTags] = (0, react_1.useState)(true);
    const [textInput, setTextInput] = (0, react_1.useState)('');
    const tagInputRef = (0, react_1.useRef)(null);
    const defaultStyles = AutocompleteStyles(theme, filterOptions, hideDropDownTags);
    const handleTextInputPress = () => {
        tagInputRef.current?.focus();
    };
    const handleTextInputFocus = () => {
        setHideDropDownTags(false);
    };
    const handleOnBlurTags = () => {
        setHideDropDownTags(true);
    };
    const handleOnChangeText = (text) => {
        if (text.length <= limitCharacterCountTag && value.length < limitTags) {
            setTextInput(text);
            const searchData = filterChips(options, value);
            let arr;
            if (text === '') {
                arr = searchData;
            }
            else {
                arr = searchData.filter((str) => str.toLowerCase().includes(text.toLowerCase()));
            }
            setFilterOptions(arr);
        }
    };
    const handleSubmitText = () => {
        if (value.length < limitTags && textInput.length >= 1) {
            if (allowCustomtag === true || filterOptions.includes(textInput)) {
                const newChip = [...value];
                newChip.push(textInput);
                setFilterOptions(filterChips(options, newChip));
                setTextInput('');
                if (onChange) {
                    onChange(newChip);
                }
            }
        }
    };
    const onTagsSelected = (tag) => {
        if (value.length < limitTags) {
            const newChip = [...value];
            newChip.push(tag);
            setFilterOptions(filterChips(options, newChip));
            setTextInput('');
            if (onChange) {
                onChange(newChip);
            }
        }
    };
    const removeChipItem = (item) => {
        const arr = value.filter((str) => str !== item);
        setFilterOptions(filterChips(options, arr));
        if (onDelete) {
            onDelete(item);
        }
    };
    return (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.individualTextInputWrapper, defaultStyles.tagInputWrapper, styles?.root] },
        react_1.default.createElement(react_native_1.View, null,
            react_1.default.createElement(react_native_1.TouchableHighlight, { onPress: handleTextInputPress },
                react_1.default.createElement(react_native_1.View, { style: defaultStyles.selectorContainer },
                    react_1.default.createElement(react_native_1.View, { style: { width: '93%' } },
                        !hideDropDownTags || value.length > 0 ? (react_1.default.createElement(react_native_paper_1.HelperText, { style: defaultStyles.labelStyle, type: "info" },
                            !hideDropDownTags || value.length > 0 ? label : '',
                            ' ')) : null,
                        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.tagInput, styles?.textInputContainer] },
                            value.map((item) => (react_1.default.createElement(Chip_1.Chip, { key: item, style: [defaultStyles.chip, styles?.chip], borderColor: theme.colors.outline, textColor: theme.colors.onSurfaceVariant, disabled: disabled, onClose: () => {
                                    removeChipItem(item);
                                }, ...chipProps }, item))),
                            react_1.default.createElement(react_native_1.TextInput, { testID: "tagInput", ref: tagInputRef, selectionColor: theme.colors.primary, value: textInput, placeholderTextColor: theme.colors.onSurfaceVariant, placeholder: hideDropDownTags && value.length < 1 ? label : '', onChangeText: (e) => handleOnChangeText(e), style: [defaultStyles.tagTextInput, styles?.textInput], onBlur: handleOnBlurTags, onFocus: handleTextInputFocus, blurOnSubmit: false, onSubmitEditing: handleSubmitText, autoCorrect: false, editable: !disabled && value.length < limitTags, ...tagInputFieldProps }))),
                    react_1.default.createElement(react_native_1.View, { style: defaultStyles.iconWrapper }, hideDropDownTags ? (react_1.default.createElement(MaterialIcons_1.default, { name: "arrow-drop-down", size: 24 })) : (react_1.default.createElement(MaterialIcons_1.default, { name: "arrow-drop-up", size: 24 })))))),
        !hideDropDownTags && !disabled && (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.dropDownMenuTags, styles?.dropdownContainer] },
            react_1.default.createElement(react_native_1.ScrollView, { testID: "dropDownMenuTags", nestedScrollEnabled: true, keyboardShouldPersistTaps: "handled" }, filterOptions.map((item, index) => (react_1.default.createElement(react_native_1.TouchableOpacity, { key: index, style: [defaultStyles.dropDownItem, styles?.dropdownItem], onPress: () => onTagsSelected(item) },
                react_1.default.createElement(react_native_paper_1.Text, { style: [defaultStyles.optionText] }, item))))))),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.helpersWrapper, styles?.helperContainer] },
            react_1.default.createElement(react_native_paper_1.HelperText, { type: "info", style: [defaultStyles.helper, styles?.helperText], visible: true }, helperText ? helperText : ''),
            react_1.default.createElement(react_native_paper_1.HelperText, { type: "info", visible: true, style: [defaultStyles.counterHelper, styles?.helperCounter] },
                textInput.length,
                " / ",
                limitCharacterCountTag)),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.bottomMargin] })));
};
exports.AutoComplete = AutoComplete;
