"use strict";
/**
 * @format
 * @flow
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Grade = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const react_native_themes_1 = require("@brightlayer-ui/react-native-themes");
const shared_1 = require("../Utility/shared");
const hexToRgb = (hex) => {
    const hexcode = hex.replace('#', '');
    const bigint = parseInt(hexcode, 16);
    const r = (bigint >> 16) & 255;
    const g = (bigint >> 8) & 255;
    const b = bigint & 255;
    return [r, g, b];
};
const mixColors = (color1, color2, percentage1, percentage2, transparency = 1.0) => {
    if (percentage1 < 0 || percentage1 > 100 || percentage2 < 0 || percentage2 > 100) {
        throw new Error('Percentages must be between 0 and 100');
    }
    if (transparency < 0 || transparency > 1) {
        throw new Error('Transparency must be between 0 and 1');
    }
    const rgb1 = Array.isArray(color1) ? color1.slice(0, 3) : hexToRgb(color1);
    const rgb2 = Array.isArray(color2) ? color2.slice(0, 3) : hexToRgb(color2);
    const mixedRgb = [
        Math.round(rgb1[0] * (percentage1 / 100) + rgb2[0] * (percentage2 / 100)),
        Math.round(rgb1[1] * (percentage1 / 100) + rgb2[1] * (percentage2 / 100)),
        Math.round(rgb1[2] * (percentage1 / 100) + rgb2[2] * (percentage2 / 100)),
    ];
    const mixedColor = `rgba(${mixedRgb[0]}, ${mixedRgb[1]}, ${mixedRgb[2]}, ${transparency})`;
    return mixedColor;
};
const GradeBase = (props) => {
    const defaultTheme = (0, react_native_themes_1.useExtendedTheme)();
    const { label, fontColor, backgroundColor, size = 40, styles = {}, style, theme: themeOverride, ...otherViewProps } = props;
    const theme = (0, react_native_themes_1.useExtendedTheme)(themeOverride || props.theme || defaultTheme);
    // Define styles for Avatar.Text component
    const avatarStyle = {
        backgroundColor: backgroundColor || theme.colors.primary,
    };
    // Define styles for text within Avatar.Text
    const textStyle = {
        color: fontColor || theme.colors.onPrimary,
        ...shared_1.fontStyleBold,
    };
    return (react_1.default.createElement(react_native_paper_1.Avatar.Text, { label: label, style: [avatarStyle, styles.root, style], color: fontColor, labelStyle: textStyle, size: size, testID: "grade", ...otherViewProps }));
};
/**
 * A component used to render an A+ Grade
 */
GradeBase.APlus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'A+', fontColor: theme.colors.onSuccessFilledContainer, backgroundColor: theme.colors.successFilledContainer, ...props }));
};
/**
 * A component used to render an A Grade
 */
GradeBase.A = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'A', fontColor: theme.colors.onSuccessFilledContainer, backgroundColor: theme.colors.successFilledContainer, ...props }));
};
/**
 * A component used to render an A- Grade
 */
GradeBase.AMinus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'A-', fontColor: theme.colors.onSuccessFilledContainer, backgroundColor: mixColors(theme.colors.warningFilledContainer, theme.colors.successFilledContainer, 33, 67), ...props }));
};
/**
 * A component used to render a B+ Grade"
 */
GradeBase.BPlus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'B+', fontColor: theme.colors.onWarningFilledContainer, backgroundColor: mixColors(theme.colors.warningFilledContainer, theme.colors.successFilledContainer, 67, 33), ...props }));
};
/**
 * A component used to render a B Grade
 */
GradeBase.B = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'B', fontColor: theme.colors.onWarningFilledContainer, backgroundColor: theme.colors.warningFilledContainer, ...props }));
};
/**
 * A component used to render a B- Grade
 */
GradeBase.BMinus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'B-', fontColor: theme.colors.onWarningFilledContainer, backgroundColor: mixColors(theme.colors.orangeFilledContainer, theme.colors.warningFilledContainer, 33, 67), ...props }));
};
/**
 * A component used to render a C+ Grade
 */
GradeBase.CPlus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'C+', fontColor: theme.colors.onOrangeFilledContainer, backgroundColor: mixColors(theme.colors.orangeFilledContainer, theme.colors.warningFilledContainer, 67, 33), ...props }));
};
/**
 * A component used to render a C Grade
 */
GradeBase.C = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'C', fontColor: theme.colors.onOrangeFilledContainer, backgroundColor: theme.colors.orangeFilledContainer, ...props }));
};
/**
 * A component used to render a C- Grade
 */
GradeBase.CMinus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'C-', fontColor: theme.colors.onOrangeFilledContainer, backgroundColor: mixColors(theme.colors.errorFilledContainer, theme.colors.orangeFilledContainer, 33, 67), ...props }));
};
/**
 * A component used to render a D+ Grade
 */
GradeBase.DPlus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'D+', fontColor: theme.colors.onErrorFilledContainer, backgroundColor: mixColors(theme.colors.errorFilledContainer, theme.colors.orangeFilledContainer, 67, 33), ...props }));
};
/**
 * A component used to render a D Grade
 */
GradeBase.D = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'D', fontColor: theme.colors.onErrorFilledContainer, backgroundColor: theme.colors.errorFilledContainer, ...props }));
};
/**
 * A component used to render a D- Grade
 */
GradeBase.DMinus = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'D-', fontColor: theme.colors.onErrorFilledContainer, backgroundColor: theme.colors.errorFilledContainer, ...props }));
};
/**
 * A component used to render an F Grade
 */
GradeBase.F = (props) => {
    const theme = (0, react_native_themes_1.useExtendedTheme)();
    return (react_1.default.createElement(GradeBase, { label: 'F', fontColor: theme.colors.onPurpleFilledContainer, backgroundColor: theme.colors.purpleFilledContainer, ...props }));
};
/**
 * A component used to render a score/grade inside of an Avatar. Includes several sub-components with predefined styles for several common grades.
 */
exports.Grade = GradeBase;
/**
 * A component used to render a score/grade inside of an Avatar. Includes several sub-components with predefined styles for several common grades.
 */
exports.default = exports.Grade;
