"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InfoListItem = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const MaterialCommunityIcons_1 = __importDefault(require("react-native-vector-icons/MaterialCommunityIcons"));
const react_native_paper_1 = require("react-native-paper");
const utilities_1 = require("./utilities");
const Icon_1 = require("../Icon");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const react_native_themes_1 = require("@brightlayer-ui/react-native-themes");
const shared_1 = require("../Utility/shared");
const getIconAlignment = (iconAlign) => {
    switch (iconAlign) {
        case 'right':
            return 'flex-end';
        case 'center':
            return 'center';
        case 'left':
        default:
            return 'flex-start';
    }
};
/**
 * Divider component
 *
 * A utility component for rendering a horizontal rule. This is a wrapper around the
 * react-native-paper Divider component that gives us the ability to do a partial or
 * full width divider.
 */
const Divider = (props) => {
    const { divider, fontScale = 1 } = props;
    if (divider) {
        return (react_1.default.createElement(react_native_1.View, { style: {
                position: 'absolute',
                bottom: 0,
                right: react_native_1.I18nManager.isRTL ? (divider === 'full' ? 0 : 72 * fontScale) : 0,
                left: !react_native_1.I18nManager.isRTL ? (divider === 'full' ? 0 : 72 * fontScale) : 0,
                alignItems: 'stretch',
            } },
            react_1.default.createElement(react_native_paper_1.Divider, null)));
    }
    return null;
};
const infoListItemStyles = (props, theme, fontScale) => {
    const isWrapEnabled = props.wrapSubtitle || props.wrapTitle || props.wrapInfo;
    return react_native_1.StyleSheet.create({
        root: {
            backgroundColor: props.backgroundColor || 'transparent',
            minHeight: isWrapEnabled ? (props.dense ? 56 : 72) * fontScale : 'auto',
            height: !isWrapEnabled ? (props.dense ? 56 : 72) * fontScale : 'auto',
            flexDirection: 'row',
            alignItems: 'center',
            paddingLeft: 16,
            paddingRight: 16,
            paddingTop: 8,
            paddingBottom: 8,
        },
        title: {
            color: props.fontColor || theme.colors.onSurface,
            ...shared_1.fontStyleSemiBold,
        },
        subtitleWrapper: {
            flexDirection: 'row',
            alignItems: 'center',
            overflow: 'hidden',
        },
        subtitle: {
            color: props.fontColor || theme.colors.onSurfaceVariant,
        },
        infoWrapper: {
            flexDirection: 'row',
            alignItems: 'center',
        },
        info: {
            color: props.fontColor || theme.colors.onSurfaceVariant,
        },
        statusStripe: {
            position: 'absolute',
            top: 0,
            left: 0,
            bottom: 0,
            width: 6,
            backgroundColor: props.statusColor,
        },
        iconWrapper: {
            width: 40 * fontScale,
            alignItems: 'flex-start',
            justifyContent: 'center',
        },
        avatar: {
            width: 40 * fontScale,
            height: 40 * fontScale,
            borderRadius: 20 * fontScale,
            alignItems: 'center',
            justifyContent: 'center',
            backgroundColor: props.statusColor || theme.colors.neutralFilledContainer,
        },
        icon: {
            width: 40 * fontScale,
            height: 40 * fontScale,
            backgroundColor: 'transparent',
            justifyContent: 'center',
            alignItems: getIconAlignment(props.iconAlign),
        },
        mainContent: {
            flex: 1,
            paddingHorizontal: props.hidePadding ? 0 : 16,
        },
        flipIcon: {
            transform: [{ scaleX: -1 }],
        },
    });
};
/**
 * [InfoListItem](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--info-list-item) component
 *
 * The InfoListItem is a component used to render lists. It extends the basic implementation
 * of a list item with additional features, such as icons and status stripes and supplies all of
 * the correct Brightlayer UI styles.
 */
const InfoListItem = (props) => {
    const { avatar, title, wrapTitle, leftComponent, rightComponent, chevron, divider, subtitle, wrapSubtitle, subtitleSeparator, info, wrapInfo, statusColor, dense, //eslint-disable-line @typescript-eslint/no-unused-vars
    fontColor, //eslint-disable-line @typescript-eslint/no-unused-vars
    iconAlign, //eslint-disable-line @typescript-eslint/no-unused-vars
    iconColor, backgroundColor, //eslint-disable-line @typescript-eslint/no-unused-vars
    onPress, icon, hidePadding, styles = {}, theme: themeOverride, style, ...viewProps } = props;
    const theme = (0, react_native_themes_1.useExtendedTheme)(themeOverride);
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const { disableScaling, maxScale } = (0, font_scale_context_1.useFontScaleSettings)();
    const defaultStyles = infoListItemStyles(props, theme, fontScale);
    const getIconColor = (0, react_1.useCallback)(() => {
        if (iconColor)
            return iconColor;
        if (avatar) {
            return theme.colors.onNeutralFilledContainer;
        }
        return statusColor ? statusColor : theme.colors.onSurfaceVariant;
    }, [iconColor, avatar, statusColor, theme]);
    const getIcon = (0, react_1.useCallback)(() => {
        if (icon) {
            return (react_1.default.createElement(react_native_1.View, { style: avatar ? [defaultStyles.avatar, styles.avatar] : [defaultStyles.icon, styles.icon] },
                react_1.default.createElement(Icon_1.Icon, { source: icon, size: 24, color: getIconColor() })));
        }
    }, [icon, avatar, getIconColor, defaultStyles, styles]);
    const getSubtitle = (0, react_1.useCallback)(() => {
        if (!subtitle) {
            return null;
        }
        const subtitleParts = Array.isArray(subtitle) ? [...subtitle] : [subtitle];
        const renderableSubtitleParts = subtitleParts.map((element) => (0, utilities_1.renderableSubtitleComponent)(element, Object.assign({}, defaultStyles.subtitle, styles.subtitle), wrapSubtitle));
        return (0, utilities_1.withKeys)((0, utilities_1.separate)(renderableSubtitleParts, subtitleSeparator));
    }, [subtitle, subtitleSeparator, styles]);
    const getInfo = (0, react_1.useCallback)(() => {
        if (!info) {
            return null;
        }
        const infoParts = Array.isArray(info) ? [...info] : [info];
        const renderableInfoParts = infoParts.map((element) => (0, utilities_1.renderableInfoComponent)(element, Object.assign({}, defaultStyles.info, styles.info), wrapInfo));
        return (0, utilities_1.withKeys)((0, utilities_1.separate)(renderableInfoParts, subtitleSeparator));
    }, [info, subtitleSeparator, styles]);
    const getRightComponent = (0, react_1.useCallback)(() => (react_1.default.createElement(react_1.default.Fragment, null,
        rightComponent && rightComponent,
        chevron && (react_1.default.createElement(MaterialCommunityIcons_1.default, { name: "chevron-right", size: 24, color: theme.colors.onSurfaceVariant, allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale, style: react_native_1.I18nManager.isRTL ? defaultStyles.flipIcon : {} })))), [rightComponent, chevron, theme]);
    return (react_1.default.createElement(react_native_1.TouchableOpacity, { accessible: true, testID: `list-item-${title.replace(/\s+/g, '-').toLowerCase()}`, accessibilityLabel: `list-item-${title.replace(/\s+/g, '-').toLowerCase()}`, onPress: onPress, style: [defaultStyles.root, styles.root, style], disabled: !onPress, activeOpacity: 0.7, ...viewProps },
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.statusStripe, styles.statusStripe] }),
        icon || !hidePadding ? (react_1.default.createElement(react_native_1.View, { style: [defaultStyles.iconWrapper, styles.iconWrapper] }, getIcon())) : null,
        leftComponent,
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.mainContent, styles.mainContent] },
            react_1.default.createElement(react_native_paper_1.Text, { variant: 'titleMedium', style: [defaultStyles.title, styles.title], numberOfLines: wrapTitle ? 0 : 1, ellipsizeMode: 'tail' }, title),
            react_1.default.createElement(react_native_1.View, { style: [defaultStyles.subtitleWrapper, styles.subtitleWrapper] }, getSubtitle()),
            react_1.default.createElement(react_native_1.View, { style: [defaultStyles.infoWrapper, styles.infoWrapper] }, getInfo())),
        getRightComponent(),
        react_1.default.createElement(Divider, { divider: divider, fontScale: fontScale })));
};
exports.InfoListItem = InfoListItem;
